diff --git a/data/translations/Internationalization_fa.ts b/data/translations/Internationalization_fa.ts
index 4359d952..f3d09b55 100644
--- a/data/translations/Internationalization_fa.ts
+++ b/data/translations/Internationalization_fa.ts
@@ -427,7 +427,7 @@ Press Space to open the side panel.
Esc
- گریز
+ گریز
@@ -445,7 +445,7 @@ Press Space to open the side panel.
Update
- بهروز رسانی
+ بهروز رسانی
@@ -806,7 +806,7 @@ Please solve them manually in the configuration file.
Unable to close active modal widgets
- ناتوان در بستن ابزارکهای پرکاربرد فعّال
+ ناتوان در بستن ابزارکهای فعّال
@@ -819,17 +819,17 @@ Please solve them manually in the configuration file.
New version %1 is available
- نگارش جدید %1 در دسترس است
+ نگارش جدید %1 در دسترس استYou have the latest version
- شما آخرین نگارش را دارید
+ شما آخرین نگارش را داریدFailed to get information about the latest version.
- دریافت اطّلاعات درباره آخرین نگارش شکست خورد.
+ دریافت اطّلاعات درباره آخرین نگارش ناموفق بود.
@@ -1675,7 +1675,7 @@ Please solve them manually in the configuration file.
Copy to clipboard
- Copia al porta-retalls
+ ذخیره در بُریدهدان
@@ -2223,77 +2223,77 @@ You may need to escape the '#' sign as in '\#FFF'
Left Double-click
-
+ دوبار کلیکToggle side panel
- تغییر وضعیت تابلو کناری
+ تغییر وضعیت تابلو کناریResize selection left 1px
- تغییر اندازه محوطه گزیده شده 1 پیکسل به چپ
+ تغییر اندازه محوطه گزیده شده 1 پیکسل به چپResize selection right 1px
- تغییر اندازه محوطه گزیده شده 1 پیکسل به راست
+ تغییر اندازه محوطه گزیده شده 1 پیکسل به راستResize selection up 1px
- تغییر اندازه محوطه گزیده شده 1 پیکسل به بالا
+ تغییر اندازه محوطه گزیده شده 1 پیکسل به بالاResize selection down 1px
- تغییر اندازه محوطه گزیده شده 1 پیکسل به پایین
+ تغییر اندازه محوطه گزیده شده 1 پیکسل به پایینSelect entire screen
- گزینش کل صفحه
+ انتخاب تمام صفحهMove selection left 1px
- جابهجایی محوطه گزیده شده 1 پیکسل به چپ
+ جابهجایی محوطه گزیده شده 1 پیکسل به چپMove selection right 1px
- جابهجایی محوطه گزیده شده 1 پیکسل به راست
+ جابهجایی محوطه گزیده شده 1 پیکسل به راستMove selection up 1px
- جابهجایی محوطه گزیده شده 1 پیکسل به بالا
+ جابهجایی محوطه گزیده شده 1 پیکسل به بالاMove selection down 1px
- جابهجایی محوطه گزیده شده 1 پیکسل به پایین
+ جابهجایی محوطه گزیده شده 1 پیکسل به پایینCommit text in text area
- متن ثبت در ناحیهٔ متنی
+ ثبت متن در ناحیهٔ متنیDelete current tool
- حذف ابزار فعلی
+ حذف ابزار فعلیCapture screen
- نماگرفت از صفحه
+ نماگرفت از صفحهScreenshot history
- تاریخچهٔ نماگرفت
+ تاریخچهٔ نماگرفت
@@ -2541,42 +2541,42 @@ You may need to escape the '#' sign as in '\#FFF'
&Take Screenshot
- &گرفتن نماگرفت
+ &گرفتن نماگرفت&Open Launcher
- &گشودن اجراگر
+ &گشودن اجراگر&Configuration
- &پیکربندی
+ &پیکربندی&About
- &درباره
+ &درباره نرمافزارCheck for updates
- بررسی برای بهروز رسانیها
+ بررسی برای بهروز رسانیNew version %1 is available
- نگارش جدید %1 در دسترس است
+ نگارش جدید %1 در دسترس است&Quit
- &خروج
+ &خروج&Latest Uploads
- &جدیدترین بارگذاریها
+ &آخرین بارگذاریها
diff --git a/data/translations/Internationalization_fi.ts b/data/translations/Internationalization_fi.ts
index 4987b6e2..55eaa40d 100644
--- a/data/translations/Internationalization_fi.ts
+++ b/data/translations/Internationalization_fi.ts
@@ -11,12 +11,12 @@
Move Up
- Siirry ylös
+ Siirrä ylösMove Down
- Siirry alas
+ Siirrä alas
@@ -47,7 +47,7 @@
Choose an app to open the capture
- Valitse millä sovelluksella kaappaus avataan
+ Valitse sovellus jossa kaappaus avataan
@@ -94,7 +94,7 @@
Set the Arrow as the paint tool
- Aseta nuoli maalaustyökaluksi
+ Aseta nuoli työkalu
@@ -154,7 +154,7 @@
Take new screenshot
- Ota uusi kuvakaappaus
+ Ota uusi kaappaus
@@ -170,7 +170,7 @@
Capture Launcher
- Capture Launcher
+ Kaappauksen laukaisija
@@ -178,7 +178,7 @@
TextLabel
- TextLabel
+ Tekstinimi
@@ -202,7 +202,7 @@
WxH+x+y
- WxH+x+y
+ LxK+x+y
@@ -211,7 +211,7 @@
Unable to capture screenImpossible capturar la pantalla
- Näytönkaappaus ei onnistunut
+ Kaappaaminen ei onnistunut
@@ -221,7 +221,7 @@
Select screenshot area
- Valitse kuvakaappauksen alue
+ Valitse kaappauksen alue
@@ -236,7 +236,7 @@
Right Click
- Hiiren oikea napsautus
+ Hiiren oikea näppäin
@@ -266,7 +266,7 @@
Configuration error resolved. Launch `flameshot gui` again to apply it.
- Configuration error resolved. Launch `flameshot gui` again to apply it.
+ Määritysvirhe ratkaistu. Käynnistä "flameshot gui" uudelleen ottaaksesi sen käyttöön.Select an area with the mouse, or press Esc to exit.
@@ -296,7 +296,7 @@ Paina väliyöntiä avataksesi sivupaneelin.
Add an autoincrementing counter bubble
- Lisää automaattisesti kasvava laskurikupla
+ Lisää laskurikupla, automaattisesti kasvava
@@ -304,12 +304,12 @@ Paina väliyöntiä avataksesi sivupaneelin.
Circle
- Kehä
+ YmpyräSet the Circle as the paint tool
- Aseta ympyrä maalaustyökaluksi
+ Aseta ympyrä työkalu
@@ -397,17 +397,17 @@ Paina väliyöntiä avataksesi sivupaneelin.
Enter or Left Click
-
+ Enter tai hiiren vasen painikePrecisely select color
- Precisely select color
+ Valitse tarkka väriHold Left Click
-
+ Pidä hiiren vasen painettuna
@@ -417,7 +417,7 @@ Paina väliyöntiä avataksesi sivupaneelin.
Space or Right Click
-
+ Välilyönti tai hiiren oikea
@@ -427,7 +427,7 @@ Paina väliyöntiä avataksesi sivupaneelin.
Esc
- Esc
+ Esc
@@ -439,22 +439,22 @@ Paina väliyöntiä avataksesi sivupaneelin.
Edit Preset:
- Edit Preset:
+ Muokkaa asetusta:Enter color to update preset
- Enter color to update preset
+ Anna väri päivittääksesi asetuksenUpdate
- Päivitä
+ PäivitäPress button to update the selected preset
- Press button to update the selected preset
+ Paina painiketta päivittääksesi valitun asetuksen
@@ -500,7 +500,7 @@ Paina väliyöntiä avataksesi sivupaneelin.
Unable to remove preset. Minimum limit reached.
- Unable to remove preset. Minimum limit reached.
+ Asetusta ei voida poistaa. Minimiraja saavutettu.
@@ -524,37 +524,37 @@ Paina väliyöntiä avataksesi sivupaneelin.
Unrecognized shortcut name: '%1'.
- Unrecognized shortcut name: '%1'.
+ Tuntematon pikanäppäimen nimi: "%1".
Shortcut conflict: '%1' and '%2' have the same shortcut: %3
- Shortcut conflict: '%1' and '%2' have the same shortcut: %3
+ Pikanäppäimen ristiriita: "%1" ja "%2" on sama näppäin: %3
Bad value in '%1'. Expected: %2
- Bad value in '%1'. Expected: %2
+ Virheellinen arvo "%1". Odotettu: %2
You have successfully resolved the configuration error.
- You have successfully resolved the configuration error.
+ Olet ratkaissut määritysvirheen.The configuration contains an error. Open configuration to resolve.
- The configuration contains an error. Open configuration to resolve.
+ Määritys sisältää virheen. Avaa määritykset ja korjaa.Bad config key '%1' in ConfigHandler. Please report this as a bug.
- Bad config key '%1' in ConfigHandler. Please report this as a bug.
+ Virheellinen asetusavain "%1" ConfigHandler:ssa. Ilmoita tämä virhe.
@@ -594,9 +594,9 @@ Paina väliyöntiä avataksesi sivupaneelin.
Some keyboard shortcuts have conflicts.
This will NOT prevent flameshot from starting.
Please solve them manually in the configuration file.
- Some keyboard shortcuts have conflicts.
-This will NOT prevent flameshot from starting.
-Please solve them manually in the configuration file.
+ Joissakin pikanäppäimissä on ristiriitoja.
+Tämä ei estä flameshot-ohjelmaa käynnistymästä.
+Ratkaise ne käsin muuttamalla asetustiedostoa.
@@ -745,7 +745,7 @@ Please solve them manually in the configuration file.
Leave the capture screen
- Jätä kaappausnäyttö
+ Poistu kaappauksesta
@@ -763,7 +763,7 @@ Please solve them manually in the configuration file.
Preview:
- Esikatsele:
+ Esikatselu:
@@ -810,12 +810,12 @@ Please solve them manually in the configuration file.
Unable to close active modal widgets
- Aktiivisia modaalisia widgettejä ei voi sulkea
+ Aktiivisia modaalisia widgettejä ei voi sulkeaURL copied to clipboard.
- URL copied to clipboard.
+ URL-osoite kopioitu leikepöydälle.
@@ -823,17 +823,17 @@ Please solve them manually in the configuration file.
New version %1 is available
- Uusi versio %1 on saatavilla
+ Uusi versio %1 on saatavillaYou have the latest version
- Sinulla on uusin versio
+ Sinulla on uusin versioFailed to get information about the latest version.
- Uusimman version tietojen saaminen epäonnistui.
+ Uusimman version tietojen saaminen epäonnistui.
@@ -971,12 +971,12 @@ Please solve them manually in the configuration file.
Show desktop notifications
- Näytä työpöytäilmoitukset
+ Näytä ilmoituksetShow tray icon
- Näytä ilmoitusalueen kuvake
+ Näytä kuvake paneelissaShow the systemtray icon
@@ -985,7 +985,7 @@ Please solve them manually in the configuration file.
Confirmation required to delete screenshot from the latest uploads
- Vahvistus tarvitaan kuvakaappauksen poistamiseksi viimeisimmistä latauksista
+ Vahvistus tarvitaan kaappauksen poistamiseksi uusimmista latauksista
@@ -1010,7 +1010,7 @@ Please solve them manually in the configuration file.
Allow multiple flameshot GUI instances simultaneously
- Salli useita Flameshotin käyttöliittymän ilmentymiä samanaikaisesti
+ Salli useita Flameshot käyttöliittymiä samanaikaisesti
@@ -1063,12 +1063,12 @@ Please solve them manually in the configuration file.
Use last region
- Use last region
+ Käytä viimeistä aluettaUses the last region as the default selection for the next screenshot
- Uses the last region as the default selection for the next screenshot
+ Käyttää viimeistä aluetta seuraavan kaappauksen oletusvalintana
@@ -1078,7 +1078,7 @@ Please solve them manually in the configuration file.
Enable desktop notifications
- Käytä työpöytäilmoituksia
+ Käytä ilmoituksia
@@ -1088,7 +1088,7 @@ Please solve them manually in the configuration file.
Ask for confirmation to delete screenshot from the latest uploads
- Kysy vahvistus kuvakaappauksen poistamiseksi viimeisimmistä lähetyksistä
+ Kysy vahvistus kaappauksen poistamiseksi uusimmista lähetyksistä
@@ -1098,7 +1098,7 @@ Please solve them manually in the configuration file.
This allows you to take screenshots of Flameshot itself for example
- Tämä sallii kuvakaappauksen ottamisen esimerkiksi itse Flameshotista
+ Tämä sallii kaappauksen ottamisen esimerkiksi itse Flameshotista
@@ -1108,7 +1108,7 @@ Please solve them manually in the configuration file.
Show the welcome message box in the middle of the screen while taking a screenshot
- Show the welcome message box in the middle of the screen while taking a screenshot
+ Näytä tervetuloa viestiruutu näytön keskellä, kun otat kaappauksen
@@ -1118,12 +1118,12 @@ Please solve them manually in the configuration file.
Copy on double click
- Copy on double click
+ Kopioi napsauttamalla kahdestiEnable Copy on Double Click
- Enable Copy on Double Click
+ Ota kopiointi käyttöön kaksoisnapsautuksella
@@ -1133,7 +1133,7 @@ Please solve them manually in the configuration file.
After copying the screenshot, save it to a file as well
- Kuvakaappauksen ottamisen jälkeen tallenna se tiedostoksi
+ Kaappauksen ottamisen jälkeen tallenna se tiedostoksi
@@ -1148,12 +1148,12 @@ Please solve them manually in the configuration file.
Use fixed path for screenshots to save
- Käytä kiinteää polkua kuvakaappausten tallentamiseen
+ Käytä kiinteää polkua kaappausten tallentamiseenPreferred save file extension:
- Ensisijainen tallennuksen tiedostopääte:
+ Tallennuksen tiedostopääte:
@@ -1163,7 +1163,7 @@ Please solve them manually in the configuration file.
Imgur Application Client ID
- Imgur Application Client ID
+ Imgur-sovelluksen asiakastunnus
@@ -1189,12 +1189,12 @@ Please solve them manually in the configuration file.
Anti-aliasing image when zoom the pinned image
- Anti-aliasing image when zoom the pinned image
+ Pehmennä, kun skaalataan kiinnitettyä kuvaaAfter zooming the pinned image, should the image get smoothened or stay pixelated
- After zooming the pinned image, should the image get smoothened or stay pixelated
+ Kun kiinnitettyä kuvaa on suurennettu, pitäisikö kuvan tasoittua vai pysyä pikselimäisenä
@@ -1220,7 +1220,7 @@ Please solve them manually in the configuration file.
Enable a magnifier while selecting the screenshot area
- Käytä suurenuslasia kun kuvakaappauksen aluetta valitaan
+ Käytä suurenuslasia kun kaapattavaa aluetta valitaan
@@ -1383,17 +1383,17 @@ Please solve them manually in the configuration file.
Screenshot copied to clipboard.
- Kuvakaappaus kopioitu leikepöydälle.
+ Kaappaus kopioitu leikepöydälle.Unable to save the screenshot to disk.
- Kuvakaappauksen tallentaminen levylle ei onnistu.
+ Kaappauksen tallentaminen levylle ei onnistu.Screenshot saved.
- Kuvakaappaus tallennettu.
+ Kaappaus tallennettu.
@@ -1406,7 +1406,7 @@ Please solve them manually in the configuration file.
Upload the selection
- Lähetä valinta
+ Lähetä valinta imgur.com
@@ -1438,7 +1438,7 @@ Please solve them manually in the configuration file.
Unable to open the URL.
- URL-osoitteen avaaminen ei onnistunut.
+ Osoitteen avaaminen ei onnistunut.URL copied to clipboard.
@@ -1601,7 +1601,7 @@ Please solve them manually in the configuration file.
Set Inverter as the paint tool
- Set Inverter as the paint tool
+ Aseta käänteinen väri työkalu
@@ -1609,12 +1609,12 @@ Please solve them manually in the configuration file.
Line
- Line
+ ViivaSet the Line as the paint tool
- Aseta viiva maalaustyökaluksi
+ Aseta viiva työkalu
@@ -1622,12 +1622,12 @@ Please solve them manually in the configuration file.
Marker
- Merkki
+ MerkintäkynäSet the Marker as the paint tool
- Aseta Marker maalaustyökaluksi
+ Aseta merkintäkynä työkalu
@@ -1653,7 +1653,7 @@ Please solve them manually in the configuration file.
Set the Pencil as the paint tool
- Aseta lyijykynä maalaustyökaluksi
+ Aseta kynä työkalu
@@ -1661,12 +1661,12 @@ Please solve them manually in the configuration file.
Pin Tool
- Pin Tool
+ Kiinnitys työkaluPin image on the desktop
- Pin image on the desktop
+ Kiinnitä kuva työpöydälle
@@ -1674,17 +1674,17 @@ Please solve them manually in the configuration file.
Context menu
- Context menu
+ PudotusvalikkoCopy to clipboard
- Copia al porta-retalls
+ Kopioi leikepöydälleSave to file
- Save to file
+ Tallenna tiedostoon
@@ -1697,7 +1697,7 @@ Please solve them manually in the configuration file.
Set Pixelate as the paint tool
- Set Pixelate as the paint tool
+ Aseta pikselöinti työkalu
@@ -1705,12 +1705,12 @@ Please solve them manually in the configuration file.
Failed to register %1. Error: %2
- Failed to register %1. Error: %2
+ Rekisteröinti %1 epäonnistui. Virhe: %2Failed to unregister %1. Error: %2
- Failed to unregister %1. Error: %2
+ Rekisteröinnin poisto %1 epäonnistui. Virhe: %2
@@ -1729,12 +1729,12 @@ Please solve them manually in the configuration file.
Save screenshot
- Tallenna kuvakaappaus
+ Tallenna kaappausPath copied to clipboard as
- Path copied to clipboard as
+ Polku kopioitiin leikepöydälle Saving canceled
@@ -1757,13 +1757,13 @@ Please solve them manually in the configuration file.
Capture saved as
- Capture saved as
+ Kaappaus tallennettu nimellä Error trying to save as
- Error trying to save as
+ Virhe tallentaessa nimellä
@@ -1773,12 +1773,12 @@ Please solve them manually in the configuration file.
Powerful yet simple to use screenshot software.
- Tehokas mutta silti helppokäyttöinen ohjelma kuvakaappausten ottamiseen.
+ Tehokas mutta silti helppokäyttöinen ohjelma näytön kaappausten ottamiseen.See
- See
+ Katso
@@ -1788,17 +1788,17 @@ Please solve them manually in the configuration file.
Open the capture launcher.
- Avaa kaappauskäynnistin.
+ Avaa laukaisija.Start a manual capture in GUI mode.
- Start a manual capture in GUI mode.
+ Aloita manuaalinen kaappaus GUI-tilassa.Configure
- Configure
+ Määritä
@@ -1812,7 +1812,7 @@ Please solve them manually in the configuration file.
Existing directory or new file to save to
- Existing directory or new file to save to
+ Hakemisto tai uusi tiedosto, johon haluat tallentaa
@@ -1822,12 +1822,12 @@ Please solve them manually in the configuration file.
Pin the capture to the screen
- Pin the capture to the screen
+ Kiinnitä kaappaus näytölleUpload screenshot
- Lähetä kuvakaappaus
+ Lähetä kaappaus
@@ -1837,12 +1837,12 @@ Please solve them manually in the configuration file.
Repeat screenshot with previously selected region
- Repeat screenshot with previously selected region
+ Toista kaappaus aiemmin valitulla alueellaScreenshot region to select
- Kuvakaappauksen alue valittavaksi
+ Kaappauksen alue valittavaksi
@@ -1857,12 +1857,12 @@ Please solve them manually in the configuration file.
Enable or disable the trayicon
- Enable or disable the trayicon
+ Paneelin kuvake käyttöön tai poista se käytöstäEnable or disable run at startup
- Enable or disable run at startup
+ Suorita käynnistyksen yhteydessä tai poista se käytöstä
@@ -1872,47 +1872,47 @@ Please solve them manually in the configuration file.
Show the help message in the capture mode
- Show the help message in the capture mode
+ Näytä ohjeet kaappaustilassaDefine the main UI color
- Define the main UI color
+ Määritä käyttöliittymän pääväriDefine the contrast UI color
- Define the contrast UI color
+ Määritä käyttöliittymän kontrastiväriPrint raw PNG capture
- Print raw PNG capture
+ Tulosta raaka PNG-kaappausPrint geometry of the selection in the format W H X Y. Does nothing if raw is specified
- Print geometry of the selection in the format W H X Y. Does nothing if raw is specified
+ Tulosta valinta sivuasetuksilla muodossa L K X Y. Ei tee mitään, jos raaka on määritettyDefine the screen to capture (starting from 0)
- Define the screen to capture (starting from 0)
+ Määritä kuvattava näyttö (alkaen nollasta)Invalid delay, it must be a number greater than 0
- Invalid delay, it must be a number greater than 0
+ Virheellinen viive, sen on oltava suurempi kuin 0Invalid region, use 'WxH+X+Y' or 'all' or 'screen0/screen1/...'.
- Invalid region, use 'WxH+X+Y' or 'all' or 'screen0/screen1/...'.
+ Virheellinen alue, käytä "LxK+X+Y" tai "kaikki" tai "screen0/screen1/...".Invalid path, must be an existing directory or a new file in an existing directory
- Invalid path, must be an existing directory or a new file in an existing directory
+ Virheellinen polku, pitää olla olemassa oleva hakemisto tai uusi tiedostoDefine the screen to capture
@@ -1921,7 +1921,7 @@ Please solve them manually in the configuration file.
default: screen containing the cursor
- default: screen containing the cursor
+ oletus: näyttö, joka sisältää kursorin
@@ -1937,13 +1937,13 @@ Please solve them manually in the configuration file.
- #RRRRGGGGBBBB
- Named colors like 'blue' or 'red'
You may need to escape the '#' sign as in '\#FFF'
- Invalid color, this flag supports the following formats:
-- #RGB (each of R, G, and B is a single hex digit)
+ Virheellinen väri, tämä tukee seuraavia muotoja:
+- #RGB (kukin R, G ja B on yksi heksadesimaaliluku)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
-- Named colors like 'blue' or 'red'
-You may need to escape the '#' sign as in '\#FFF'
+- Nimetyt värit kuten "sininen" tai "punainen"
+Sinun on ehkä vältettävä "#" merkkiä kuten "\#FFF"Invalid delay, it must be higher than 0
@@ -1952,7 +1952,7 @@ You may need to escape the '#' sign as in '\#FFF'
Invalid screen number, it must be non negative
- Invalid screen number, it must be non negative
+ Virheellinen näytön numero, se ei saa olla negatiivinenInvalid path, it must be a real path in the system
@@ -1961,7 +1961,7 @@ You may need to escape the '#' sign as in '\#FFF'
Invalid value, it must be defined as 'true' or 'false'
- Invalid value, it must be defined as 'true' or 'false'
+ Virheellinen arvo, se on määriteltävä "true" tai "false"
@@ -1971,7 +1971,7 @@ You may need to escape the '#' sign as in '\#FFF'
Unable to write in
- Unable to write in
+ Ei voi kirjoittaaURL copied to clipboard.
@@ -1990,7 +1990,7 @@ You may need to escape the '#' sign as in '\#FFF'
arguments
- arguments
+ argumentit
@@ -2005,22 +2005,22 @@ You may need to escape the '#' sign as in '\#FFF'
Per default runs Flameshot in the background and adds a tray icon for configuration.
- Per default runs Flameshot in the background and adds a tray icon for configuration.
+ Oletus on suorittaa Flameshot taustalla ja lisätä kuvake paneeliin määritystä varten.Hello, I'm here! Click icon in the tray to take a screenshot or click with a right button to see more options.
- Hello, I'm here! Click icon in the tray to take a screenshot or click with a right button to see more options.
+ Hei, olen täällä! Kaappaa napsauttamalla paneelin kuvaketta tai hiiren oikea lisää vaihtoehtoja.Requested screen exceeds screen count
- Requested screen exceeds screen count
+ Pyydetty näyttö ylittää näyttöjen määränFull screen screenshot pinned to screen
- Full screen screenshot pinned to screen
+ Koko näytön kaappaus kiinnitetty näyttöönToggle side panel
@@ -2078,7 +2078,7 @@ You may need to escape the '#' sign as in '\#FFF'
Screenshot history
- Kuvakaappausten historia
+ Kaappausten historia
@@ -2110,7 +2110,7 @@ You may need to escape the '#' sign as in '\#FFF'
Set the Rectangle as the paint tool
- Set the Rectangle as the paint tool
+ Aseta suorakulmio työkalu
@@ -2123,7 +2123,7 @@ You may need to escape the '#' sign as in '\#FFF'
Redo the next modification
- Redo the next modification
+ Toista muutos uudelleen
@@ -2136,7 +2136,7 @@ You may need to escape the '#' sign as in '\#FFF'
Save screenshot to a file
- Tallenna kuvakaappaus tiedostoon
+ Tallenna kaappaus tiedostoonSave the capture
@@ -2148,12 +2148,12 @@ You may need to escape the '#' sign as in '\#FFF'
Unable to detect desktop environment (GNOME? KDE? Sway? ...)
- Unable to detect desktop environment (GNOME? KDE? Sway? ...)
+ Työpöytää ei pystytä tunnistamaan (GNOME? KDE? Sway? ...)Hint: try setting the XDG_CURRENT_DESKTOP environment variable.
- Hint: try setting the XDG_CURRENT_DESKTOP environment variable.
+ Vihje: yritä asettaa XDG_CURRENT_DESKTOP ympäristömuuttuja.
@@ -2171,7 +2171,7 @@ You may need to escape the '#' sign as in '\#FFF'
Set Selection as the paint tool
- Set Selection as the paint tool
+ Aseta valinta työkalu
@@ -2179,22 +2179,22 @@ You may need to escape the '#' sign as in '\#FFF'
Set Shortcut
- Set Shortcut
+ Aseta pikanäppäinEnter new shortcut to change
- Enter new shortcut to change
+ Anna uusi pikanäppäin muuttaaksesi Press Esc to cancel or ⌘+Backspace to disable the keyboard shortcut.
- Press Esc to cancel or ⌘+Backspace to disable the keyboard shortcut.
+ Peruuta painamalla Esc tai ⌘+askelpalautin poistaaksesi pikanäppäimen käytöstä.Press Esc to cancel or Backspace to disable the keyboard shortcut.
- Press Esc to cancel or Backspace to disable the keyboard shortcut.
+ Peruuta painamalla Esc tai askelpalautin poistaaksesi pikanäppäimen käytöstä.
@@ -2212,7 +2212,7 @@ You may need to escape the '#' sign as in '\#FFF'
Available shortcuts in the screen capture mode.
- Available shortcuts in the screen capture mode.
+ Saatavilla olevat pikanäppäimet kaappaustilassa.
@@ -2222,82 +2222,82 @@ You may need to escape the '#' sign as in '\#FFF'
Key
- Key
+ AvainLeft Double-click
-
+ Vasen kaksoisnapsautusToggle side panel
- Näytä/piilota sivupaneeli
+ Näytä/piilota sivupaneeliResize selection left 1px
- Resize selection left 1px
+ Muuta valinnan kokoa vasen 1pxResize selection right 1px
- Resize selection right 1px
+ Muuta valinnan kokoa oikea 1pxResize selection up 1px
- Resize selection up 1px
+ Muuta valinnan kokoa ylös 1pxResize selection down 1px
- Resize selection down 1px
+ Muuta valinnan kokoa alas 1pxSelect entire screen
- Valitse koko näyttö
+ Valitse koko näyttöMove selection left 1px
- Move selection left 1px
+ Siirrä valinta vasen 1pxMove selection right 1px
- Move selection right 1px
+ Siirrä valinta oikea 1pxMove selection up 1px
- Move selection up 1px
+ Siirrä valinta ylös 1pxMove selection down 1px
- Move selection down 1px
+ Siirrä valinta alas 1pxCommit text in text area
- Commit text in text area
+ Liittä teksti tekstialueelleDelete current tool
- Poista nykyinen työkalu
+ Poista nykyinen työkaluCapture screen
- Kaappaa näyttö
+ Kaappaa näyttöScreenshot history
- Kuvakaappausten historia
+ Kaappausten historia
@@ -2340,7 +2340,7 @@ You may need to escape the '#' sign as in '\#FFF'
Decrease the size of the other tools
- Decrease the size of the other tools
+ Pienennä muiden työkalujen kokoa
@@ -2353,7 +2353,7 @@ You may need to escape the '#' sign as in '\#FFF'
Increase the size of the other tools
- Increase the size of the other tools
+ Suurenna muiden työkalujen kokoa
@@ -2361,12 +2361,12 @@ You may need to escape the '#' sign as in '\#FFF'
Selection Size Indicator
- Selection Size Indicator
+ Valinnan koon ilmaisinShow X and Y dimensions of the selection
- Näytä valinnan X- ja Y-ulottuvuudet
+ Näytä valinnan mitat X ja YShow the dimensions of the selection (X Y)
@@ -2378,107 +2378,107 @@ You may need to escape the '#' sign as in '\#FFF'
Century (00-99)
- Century (00-99)
+ Vuosisata (00-99)Year (00-99)
- Year (00-99)
+ Vuosi (00-99)Year (2000)
- Year (2000)
+ Vuosi (2000)Month Name (jan)
- Month Name (jan)
+ Kuukauden nimi (tam)Month Name (january)
- Month Name (january)
+ Kuukauden nimi (tammikuu)Month (01-12)
- Month (01-12)
+ Kuukausi (01-12)Week Day (1-7)
- Week Day (1-7)
+ Viikonpäivä (1-7)Week (01-53)
- Week (01-53)
+ Viikko (01-53)Day Name (mon)
- Day Name (mon)
+ Päivän nimi (ma)Day Name (monday)
- Day Name (monday)
+ Päivän nimi (maanantai)Day (01-31)
- Day (01-31)
+ Päivä (01-31)Day of Month (1-31)
- Day of Month (1-31)
+ Kuukauden päivä (1-31)Day (001-366)
- Day (001-366)
+ Vuosipäivä (001-366)Hour (00-23)
- Hour (00-23)
+ Tunti (00-23)Hour (01-12)
- Hour (01-12)
+ Tunti (01-12)Minute (00-59)
- Minute (00-59)
+ Minuutti (00-59)Second (00-59)
- Second (00-59)
+ Sekunti (00-59)Full Date (%m/%d/%y)
- Full Date (%m/%d/%y)
+ Päivämäärä (%m/%d/%y)Full Date (%Y-%m-%d)
- Full Date (%Y-%m-%d)
+ Päivämäärä (%Y-%m-%d)Time (%H-%M-%S)
- Time (%H-%M-%S)
+ Aika (%H-%M-%S)Time (%H-%M)
- Time (%H-%M)
+ Aika (%H-%M)
@@ -2514,17 +2514,17 @@ You may need to escape the '#' sign as in '\#FFF'
Left Align
- Left Align
+ Tasaa vasenCenter Align
- Center Align
+ KeskitäRight Align
- Right Align
+ Tasaa oikea
@@ -2545,42 +2545,42 @@ You may need to escape the '#' sign as in '\#FFF'
&Take Screenshot
- &Ota kuvakaappaus
+ &Ota kaappaus&Open Launcher
- &Avaa käynnistin
+ &Avaa laukaisija&Configuration
- &Asetukset
+ &Asetukset&About
- &Tietoja
+ &TietojaCheck for updates
- Tarkista päivitykset
+ Tarkista päivityksetNew version %1 is available
- Uusi versio %1 on saatavilla
+ Uusi versio %1 on saatavilla&Quit
- &Lopeta
+ &Lopeta&Latest Uploads
- &Viimeisimmät lähetykset
+ &Uusimmat lataukset
@@ -2592,12 +2592,12 @@ You may need to escape the '#' sign as in '\#FFF'
Change the color moving the selectors and see the changes in the preview buttons.
- Change the color moving the selectors and see the changes in the preview buttons.
+ Vaihda väriä siirtämällä valintaa ja katso muutokset esikatselun painikkeissa.Select a Button to modify it
- Select a Button to modify it
+ Valitse painike ja muokkaa sitä
@@ -2607,7 +2607,7 @@ You may need to escape the '#' sign as in '\#FFF'
Click on this button to set the edition mode of the main color.
- Click on this button to set the edition mode of the main color.
+ Napsauta tätä painiketta ja aseta pääväri muokkaustilaan.
@@ -2617,7 +2617,7 @@ You may need to escape the '#' sign as in '\#FFF'
Click on this button to set the edition mode of the contrast color.
- Click on this button to set the edition mode of the contrast color.
+ Napsauta tätä painiketta ja aseta kontrastiväri muokkaustilaan.
@@ -2630,7 +2630,7 @@ You may need to escape the '#' sign as in '\#FFF'
Undo the last modification
- Undo the last modification
+ Kumoa viimeisin muutos
@@ -2669,7 +2669,7 @@ You may need to escape the '#' sign as in '\#FFF'
Screenshots history is empty
- Kuvakaappausten historia on tyhjä
+ Kaappausten historia on tyhjä
@@ -2688,7 +2688,7 @@ You may need to escape the '#' sign as in '\#FFF'
TextLabel
- TextLabel
+ Tekstinimi
@@ -2714,7 +2714,7 @@ You may need to escape the '#' sign as in '\#FFF'
Are you sure you want to delete a screenshot from the latest uploads and server?
- Haluatko varmasti poistaa kuvakaappauksen viimeisimmistä lähetyksistä ja palvelimelta?
+ Haluatko varmasti poistaa kaappauksen lähetyksistä ja palvelimelta?
@@ -2735,12 +2735,12 @@ You may need to escape the '#' sign as in '\#FFF'
Opacity of area outside selection:
- Opacity of area outside selection:
+ Valinnan ulkopuolisen alueen läpinäkyvyys:UI Color Editor
- Käyttöliittymän värimuokkain
+ Käyttöliittymän väri
@@ -2827,7 +2827,7 @@ You may need to escape the '#' sign as in '\#FFF'
Revert changes to the current palette
- Revert changes to the current palette
+ Palauta muutokset nykyiseen palettiin
@@ -2890,7 +2890,7 @@ You may need to escape the '#' sign as in '\#FFF'
Failed to load the palette file
%1
- Failed to load the palette file
+ Paletin lataaminen epäonnistui
%1
diff --git a/data/translations/Internationalization_ru.ts b/data/translations/Internationalization_ru.ts
index 019aedfe..9872f022 100644
--- a/data/translations/Internationalization_ru.ts
+++ b/data/translations/Internationalization_ru.ts
@@ -260,7 +260,7 @@
Flameshot has lost focus. Keyboard shortcuts won't work until you click somewhere.
- Flameshot потерял фокус. Сочетания клавиш не будут работать, пока вы не щёлкните где-нибудь.
+ Flameshot потерял фокус. Сочетания клавиш не будут работать, пока вы не нажмёте где-нибудь.
@@ -396,7 +396,7 @@ Press Space to open the side panel.
Enter or Left Click
- Enter или левой щелчок мыши
+ Enter или нажмите левой кнопкой мыши
@@ -406,7 +406,7 @@ Press Space to open the side panel.
Hold Left Click
- Удерживать левый щелчок мыши
+ Удерживайте левую кнопку мыши
@@ -416,7 +416,7 @@ Press Space to open the side panel.
Space or Right Click
- Пробел или правый щелчок мыши
+ Пробел или нажмите правой кнопкой мыши
@@ -1205,12 +1205,12 @@ Please solve them manually in the configuration file.
Copy on double click
- Копировать двойным щелчком мыши
+ Скопировать двойным нажатием кнопки мышиEnable Copy on Double Click
- Включить копирование по двойному щелчку мыши
+ Включить копирование по двойному нажатию кнопки мыши
@@ -2208,7 +2208,7 @@ You can find me in the system tray.
Hello, I'm here! Click icon in the tray to take a screenshot or click with a right button to see more options.
- Привет! Для создания снимка щёлкните по значку в трее. Прочие функции в меню по правому щелчку.
+ Привет! Для создания снимка нажмите на значок в трее. Чтобы увидеть больше функций, нажмите правой кнопки мыши.Toggle side panel
diff --git a/data/translations/Internationalization_ta.ts b/data/translations/Internationalization_ta.ts
new file mode 100644
index 00000000..edff6755
--- /dev/null
+++ b/data/translations/Internationalization_ta.ts
@@ -0,0 +1,2923 @@
+
+
+
+
+ AbstractWidgetList
+
+
+ Add New
+
+
+
+
+ Move Up
+
+
+
+
+ Move Down
+
+
+
+
+ Remove
+
+
+
+
+ AcceptTool
+
+
+ Accept
+
+
+
+
+ Accept the capture
+
+
+
+
+ AppLauncher
+
+
+ App Launcher
+
+
+
+
+ Choose an app to open the capture
+
+
+
+
+ AppLauncherWidget
+
+
+ Open With
+
+
+
+
+ Launch in terminal
+
+
+
+
+ Keep open after selection
+
+
+
+
+
+ Error
+
+
+
+
+ Unable to launch in terminal.
+
+
+
+
+ Unable to write in
+
+
+
+
+ ArrowTool
+
+
+ Arrow
+
+
+
+
+ Set the Arrow as the paint tool
+
+
+
+
+ BlurTool
+
+ Blur
+ Desenfocament
+
+
+ Set Blur as the paint tool
+ Estableix el desenfocament com a eina de dibuix
+
+
+
+ CaptureLauncher
+
+ <b>Capture Mode</b>
+ <b>Mode de captura</b>
+
+
+
+ Rectangular Region
+
+
+
+
+ Full Screen (Current Display)
+
+
+
+
+ Full Screen (All Monitors)
+
+
+
+
+ No Delay
+
+
+
+
+ second
+
+
+
+
+
+
+
+
+ seconds
+
+
+
+
+
+
+
+ Take new screenshot
+
+
+
+
+
+
+
+ Area:
+
+
+
+
+
+
+
+ Capture Launcher
+
+
+
+
+
+
+
+ TextLabel
+
+
+
+
+
+
+
+ Capture Mode
+
+
+
+
+
+
+
+ Delay:
+
+
+
+
+
+
+
+ WxH+x+y
+
+
+
+
+ CaptureWidget
+
+
+ Unable to capture screen
+ Impossible capturar la pantalla
+
+
+
+
+ Mouse
+
+
+
+
+ Select screenshot area
+
+
+
+
+ Mouse Wheel
+
+
+
+
+ Change tool size
+
+
+
+
+ Right Click
+
+
+
+
+ Show color picker
+
+
+
+
+ Open side panel
+
+
+
+
+ Esc
+
+
+
+
+ Exit
+
+
+
+
+ Flameshot has lost focus. Keyboard shortcuts won't work until you click somewhere.
+
+
+
+
+ Configuration error resolved. Launch `flameshot gui` again to apply it.
+
+
+
+ Select an area with the mouse, or press Esc to exit.
+Press Enter to capture the screen.
+Press Right Click to show the color picker.
+Use the Mouse Wheel to change the thickness of your tool.
+Press Space to open the side panel.
+ Escolliu una àrea amb el ratolí, o premeu Esc per sortir.
+Premeu Entrar per capturar la pantalla.
+Premeu clic dret per mostrar l'eina de selecció de color.
+Gireu la rodeta del ratolí per canviar el gruix de l'eina de dibuix.
+Premeu Espai per obrir el calaix lateral.
+
+
+
+ Tool Settings
+
+
+
+
+ CircleCountTool
+
+
+ Circle Counter
+
+
+
+
+ Add an autoincrementing counter bubble
+
+
+
+
+ CircleTool
+
+
+ Circle
+
+
+
+
+ Set the Circle as the paint tool
+
+
+
+
+ ColorDialog
+
+
+
+
+
+ Select Color
+
+
+
+
+
+
+
+ Saturation
+
+
+
+
+
+
+
+ Hue
+
+
+
+
+
+
+
+ Hex
+
+
+
+
+
+
+
+ Blue
+
+
+
+
+
+
+
+ Value
+
+
+
+
+
+
+
+ Green
+
+
+
+
+
+
+
+ Alpha
+
+
+
+
+
+
+
+ Red
+
+
+
+
+ ColorGrabWidget
+
+
+ Accept color
+
+
+
+
+ Enter or Left Click
+
+
+
+
+ Precisely select color
+
+
+
+
+ Hold Left Click
+
+
+
+
+ Toggle magnifier
+
+
+
+
+ Space or Right Click
+
+
+
+
+ Cancel
+
+
+
+
+ Esc
+
+
+
+
+ ColorPickerEditor
+
+
+ Edit Preset:
+
+
+
+
+ Enter color to update preset
+
+
+
+
+ Update
+
+
+
+
+ Press button to update the selected preset
+
+
+
+
+ Delete
+
+
+
+
+ Press button to delete the selected preset
+
+
+
+
+ Add Preset:
+
+
+
+
+ Enter color manually or select it using the color-wheel
+
+
+
+
+ Add
+
+
+
+
+ Press button to add preset
+
+
+
+
+
+ Error
+
+
+
+
+ Unable to add preset. Maximum limit reached.
+
+
+
+
+ Unable to remove preset. Minimum limit reached.
+
+
+
+
+ ConfigErrorDetails
+
+
+ Configuration errors
+
+
+
+
+ ConfigHandler
+
+
+ Unrecognized setting: '%1'
+
+
+
+
+
+ Unrecognized shortcut name: '%1'.
+
+
+
+
+
+ Shortcut conflict: '%1' and '%2' have the same shortcut: %3
+
+
+
+
+
+ Bad value in '%1'. Expected: %2
+
+
+
+
+
+ You have successfully resolved the configuration error.
+
+
+
+
+ The configuration contains an error. Open configuration to resolve.
+
+
+
+
+ Bad config key '%1' in ConfigHandler. Please report this as a bug.
+
+
+
+
+ ConfigResolver
+
+
+ Resolve configuration errors
+
+
+
+
+ <b>You must resolve all errors before continuing:</b>
+
+
+
+
+ Reset
+
+
+
+
+ Reset to the default value.
+
+
+
+
+ Remove
+
+
+
+
+ Remove this setting.
+
+
+
+
+ Some keyboard shortcuts have conflicts.
+This will NOT prevent flameshot from starting.
+Please solve them manually in the configuration file.
+
+
+
+
+ Resolve all
+
+
+
+
+ Resolve all listed errors.
+
+
+
+
+ Details
+
+
+
+
+ ConfigWindow
+
+
+ Configuration
+
+
+
+
+ Interface
+
+
+
+
+ Filename Editor
+
+
+
+
+ General
+
+
+
+
+ Shortcuts
+
+
+
+
+ Resolve
+
+
+
+
+ <b>Configuration file has errors. Resolve them before continuing.</b>
+
+
+
+
+ Controller
+
+ New version %1 is available
+ La nova versió %1 ja és disponible
+
+
+ You have the latest version
+ Teniu la versió més recent
+
+
+ Failed to get information about the latest version.
+ Error a l'intentar obtenir informació sobre actualitzacions.
+
+
+ Error
+ Error
+
+
+ Unable to close active modal widgets
+ No s'han pogut tancar els widgets modals actius
+
+
+ &Open Launcher
+ &Obre el llançador d'aplicacions
+
+
+ &Configuration
+ &Ajustaments
+
+
+ &About
+ &Quant a
+
+
+ Check for updates
+ Comprova si hi ha actualitzacions disponibles
+
+
+ &Latest Uploads
+ &Últimes càrregues
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+ &Information
+ &Informació
+
+
+ &Quit
+ &Surt
+
+
+ &Take Screenshot
+ &Captura
+
+
+
+ CopyTool
+
+
+ Copy
+
+
+
+
+ Copy selection to clipboard
+
+
+
+ Copy the selection into the clipboard
+ Copia la selecció al porta-retalls
+
+
+
+ DBusUtils
+
+ Unable to connect via DBus
+ No s'ha pogut connectar mitjançant DBus
+
+
+
+ ExitTool
+
+
+ Exit
+
+
+
+
+ Leave the capture screen
+
+
+
+
+ FileNameEditor
+
+
+ Edit the name of your captures:
+
+
+
+
+ Edit:
+
+
+
+
+ Preview:
+
+
+
+
+ Save
+
+
+
+
+ Saves the pattern
+
+
+
+
+ Restore
+
+
+
+ Reset
+ Reinicialitza
+
+
+
+ Restores the saved pattern
+
+
+
+
+ Clear
+
+
+
+
+ Deletes the name
+
+
+
+
+ Flameshot
+
+
+ Error
+
+
+
+
+ Unable to close active modal widgets
+
+
+
+
+ URL copied to clipboard.
+
+
+
+
+ FlameshotDaemon
+
+
+ New version %1 is available
+
+
+
+
+ You have the latest version
+
+
+
+
+ Failed to get information about the latest version.
+
+
+
+
+ Unable to connect via DBus
+
+
+
+
+ GeneneralConf
+
+ Show help message
+ Mostra el missatge d'ajuda
+
+
+ Show the help message at the beginning in the capture mode.
+ Mostra el missatge d'ajuda en iniciar el mode de captura.
+
+
+ Show desktop notifications
+ Mostra les notificacions d'escriptori
+
+
+ Show tray icon
+ Mostra la icona en la barra de tasques
+
+
+ Show the systemtray icon
+ Mostra la icona en la barra de tasques
+
+
+ Import
+ Importar
+
+
+ Error
+ Error
+
+
+ Unable to read file.
+ Impossible llegir el fitxer.
+
+
+ Unable to write file.
+ Impossible escriure al fitxer.
+
+
+ Save File
+ Guardar Arxiu
+
+
+ Confirm Reset
+ Confirmar Reset
+
+
+ Are you sure you want to reset the configuration?
+ Esteu segur que voleu reiniciar la configuració?
+
+
+ Configuration File
+ Fitxer de Configuració
+
+
+ Export
+ Exportar
+
+
+ Reset
+ Reset
+
+
+ Launch at startup
+ Llançament a l'inici
+
+
+
+ GeneralConf
+
+
+
+ Import
+
+
+
+
+
+
+
+ Error
+
+
+
+
+ Unable to read file.
+
+
+
+
+
+ Unable to write file.
+
+
+
+
+ Save File
+
+
+
+
+ Confirm Reset
+
+
+
+
+ Are you sure you want to reset the configuration?
+
+
+
+
+ Show help message
+
+
+
+ Show the help message at the beginning in the capture mode.
+ Mostra el missatge d'ajuda en iniciar el mode de captura.
+
+
+
+ Show the side panel button
+
+
+
+ Show the side panel toggle button in the capture mode.
+ Mostra el botó del calaix lateral en el mode de captura.
+
+
+
+ Show desktop notifications
+
+
+
+
+ Show tray icon
+
+
+
+ Show the systemtray icon
+ Mostra la icona a la barra de tasques del sistema
+
+
+
+ Confirmation required to delete screenshot from the latest uploads
+
+
+
+
+ Configuration File
+
+
+
+
+ Export
+
+
+
+
+ Reset
+
+
+
+
+ Automatic check for updates
+
+
+
+
+ Allow multiple flameshot GUI instances simultaneously
+
+
+
+ This allows you to take screenshots of flameshot itself for example.
+ This allows you to take screenshots of flameshot itself for example.
+
+
+
+
+ Automatically close daemon when it is not needed
+
+
+
+
+ Launch at startup
+
+
+
+ Launch Flameshot
+ Inicia el Flameshot
+
+
+
+ Show welcome message on launch
+
+
+
+
+ Use large predefined color palette
+
+
+
+
+ Copy URL after upload
+
+
+
+ Copy URL and close window after upload
+ Copia la URL i tanca la finestra després de la càrrega
+
+
+
+ Save image after copy
+
+
+
+ Save image file after copying it
+ Desa el fitxer d'imatge després d'haver-lo copiat
+
+
+
+ Show the help message at the beginning in the capture mode
+
+
+
+
+ Use last region
+
+
+
+
+ Uses the last region as the default selection for the next screenshot
+
+
+
+
+ Show the side panel toggle button in the capture mode
+
+
+
+
+ Enable desktop notifications
+
+
+
+
+ Show icon in the system tray
+
+
+
+
+ Ask for confirmation to delete screenshot from the latest uploads
+
+
+
+
+ Check for updates automatically
+
+
+
+
+ This allows you to take screenshots of Flameshot itself for example
+
+
+
+
+ Launch Flameshot daemon when computer is booted
+
+
+
+
+ Show the welcome message box in the middle of the screen while taking a screenshot
+
+
+
+
+ Use a large predefined color palette
+
+
+
+
+ Copy on double click
+
+
+
+
+ Enable Copy on Double Click
+
+
+
+
+ Copy URL and close window after uploading was successful
+
+
+
+
+ After copying the screenshot, save it to a file as well
+
+
+
+
+ Save Path
+
+
+
+
+ Change...
+
+
+
+
+ Use fixed path for screenshots to save
+
+
+
+
+ Preferred save file extension:
+
+
+
+
+ Latest Uploads Max Size
+
+
+
+
+ Imgur Application Client ID
+
+
+
+
+ Undo limit
+
+
+
+
+
+ Use JPG format for clipboard (PNG default)
+
+
+
+
+ Copy file path after save
+
+
+
+
+ Copy the file path to clipboard after the file is saved
+
+
+
+
+ Anti-aliasing image when zoom the pinned image
+
+
+
+
+ After zooming the pinned image, should the image get smoothened or stay pixelated
+
+
+
+
+
+ Upload image without confirmation
+
+
+
+
+ Choose a Folder
+
+
+
+
+ Unable to write to directory.
+
+
+
+
+ Show magnifier
+
+
+
+
+ Enable a magnifier while selecting the screenshot area
+
+
+
+
+ Square shaped magnifier
+
+
+
+
+ Make the magnifier to be square-shaped
+
+
+
+
+ HistoryWidget
+
+ Latest Uploads
+ Últimes càrregues
+
+
+ Screenshots history is empty
+ L'historial de captures de pantalla és buit
+
+
+ Copy URL
+ Copia l'URL
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+ Open in browser
+ Obre al navegador
+
+
+ Confirm to delete
+ Confirmeu per esborrar
+
+
+ Are you sure you want to delete a screenshot from the latest uploads and server?
+ Esteu segur de voler esborrar la captura de les últimes càrregues i del servidor?
+
+
+
+ ImgS3Uploader
+
+ Uploading Image
+ S'està pujant la imatge
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+ Error
+ Error
+
+
+
+ ImgUploadDialog
+
+
+ Upload Confirmation
+
+
+
+
+ Do you want to upload this capture?
+
+
+
+
+
+ Upload without confirmation
+
+
+
+
+ ImgUploader
+
+ Uploading Image
+ S'està pujant la imatge
+
+
+ Delete image
+ Esborra la imatge
+
+
+ Unable to open the URL.
+ No es pot obrir l'URL.
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+ Screenshot copied to clipboard.
+ La captura s'ha copiat al porta-retalls.
+
+
+ Copy URL
+ Copia l'URL
+
+
+ Open URL
+ Obri l'URL
+
+
+ Image to Clipboard.
+ Imatge al porta-retalls.
+
+
+
+ ImgUploaderBase
+
+
+ Upload image
+
+
+
+
+ Uploading Image
+
+
+
+
+ Copy URL
+
+
+
+
+ Open URL
+
+
+
+
+ Delete image
+
+
+
+
+ Image to Clipboard.
+
+
+
+
+ Save image
+
+
+
+
+ Unable to open the URL.
+
+
+
+
+ URL copied to clipboard.
+
+
+
+
+ Screenshot copied to clipboard.
+
+
+
+
+ Unable to save the screenshot to disk.
+
+
+
+
+ Screenshot saved.
+
+
+
+
+ ImgUploaderTool
+
+
+ Image Uploader
+
+
+
+
+ Upload the selection
+
+
+
+
+ ImgurUploader
+
+ Upload to Imgur
+ Puja a Imgur
+
+
+ Uploading Image
+ S'està pujant la imatge
+
+
+ Copy URL
+ Copia l'URL
+
+
+ Open URL
+ Obre l'URL
+
+
+ Delete image
+ Esborra la imatge
+
+
+ Image to Clipboard.
+ Imatge al porta-retalls.
+
+
+
+ Unable to open the URL.
+
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+ Screenshot copied to clipboard.
+ La captura s'ha copiat al porta-retalls.
+
+
+
+ ImgurUploaderTool
+
+ Image Uploader
+ Puja la imatge
+
+
+ Upload the selection to Imgur
+ Puja la selecció a Imgur
+
+
+
+ InfoWindow
+
+
+
+
+
+ About
+
+
+
+
+
+
+
+ Icon
+
+
+
+
+
+
+
+ License
+
+
+
+
+
+
+
+ GPLv3+
+
+
+
+
+
+
+
+ Version
+
+
+
+
+
+
+
+ Flameshot v
+
+
+
+
+
+
+
+ OS Info
+
+
+
+
+
+
+
+ Copy Info
+
+
+
+ Right Click
+ Clic dret
+
+
+ Mouse Wheel
+ Roda del ratolí
+
+
+ Move selection 1px
+ Mou la selecció 1 px
+
+
+ Resize selection 1px
+ Redimensiona la selecció 1 px
+
+
+ Quit capture
+ Ix de la captura
+
+
+ Copy to clipboard
+ Copia al porta-retalls
+
+
+ Save selection as a file
+ Guarda la selecció com a fitxer
+
+
+ Undo the last modification
+ Desfés l'última modificació
+
+
+ Show color picker
+ Mostra el selector de color
+
+
+ Change the tool's thickness
+ Canvia el gruix de l'eina
+
+
+ Key
+ Tecla
+
+
+ Description
+ Descripció
+
+
+ <u><b>License</b></u>
+ <u><b>Llicència</b></u>
+
+
+ <u><b>Version</b></u>
+ <u><b>Versió</b></u>
+
+
+ <u><b>Shortcuts</b></u>
+ <u><b>Dreceres</b></u>
+
+
+ Available shortcuts in the screen capture mode.
+ Dreceres disponibles en el mode de captura de pantalla.
+
+
+
+ InvertTool
+
+
+ Invert
+
+
+
+
+ Set Inverter as the paint tool
+
+
+
+
+ LineTool
+
+
+ Line
+
+
+
+
+ Set the Line as the paint tool
+
+
+
+
+ MarkerTool
+
+
+ Marker
+
+
+
+
+ Set the Marker as the paint tool
+
+
+
+
+ MoveTool
+
+
+ Move
+
+
+
+
+ Move the selection area
+
+
+
+
+ PencilTool
+
+
+ Pencil
+
+
+
+
+ Set the Pencil as the paint tool
+
+
+
+
+ PinTool
+
+
+ Pin Tool
+
+
+
+
+ Pin image on the desktop
+
+
+
+
+ PinWidget
+
+
+ Context menu
+
+
+
+
+ Copy to clipboard
+
+
+
+
+ Save to file
+
+
+
+
+ PixelateTool
+
+
+ Pixelate
+
+
+
+
+ Set Pixelate as the paint tool
+
+
+
+
+ QHotkey
+
+
+ Failed to register %1. Error: %2
+
+
+
+
+ Failed to unregister %1. Error: %2
+
+
+
+
+ QObject
+
+
+
+ Capture saved to clipboard.
+
+
+
+
+ Error while saving to clipboard
+
+
+
+
+ Save screenshot
+
+
+
+
+ Path copied to clipboard as
+
+
+
+ Saving canceled
+ Saving canceled
+
+
+ Save canceled
+ Save canceled
+
+
+ Capture is saved and copied to the clipboard as
+ La captura serà desada i copiada al porta-retalls com a
+
+
+
+ Save Error
+
+
+
+
+
+ Capture saved as
+
+
+
+
+
+ Error trying to save as
+
+
+
+
+ Unable to connect via DBus
+
+
+
+
+ Powerful yet simple to use screenshot software.
+
+
+
+
+ See
+
+
+
+
+ Capture the entire desktop.
+
+
+
+
+ Open the capture launcher.
+
+
+
+
+ Start a manual capture in GUI mode.
+
+
+
+
+ Configure
+
+
+
+
+ Capture a single screen.
+
+
+
+ Path where the capture will be saved
+ Camí on es desarà la captura
+
+
+
+ Existing directory or new file to save to
+
+
+
+
+ Save the capture to the clipboard
+
+
+
+
+ Pin the capture to the screen
+
+
+
+
+ Upload screenshot
+
+
+
+
+ Delay time in milliseconds
+
+
+
+
+ Repeat screenshot with previously selected region
+
+
+
+
+ Screenshot region to select
+
+
+
+
+ Set the filename pattern
+
+
+
+
+ Accept capture as soon as a selection is made
+
+
+
+
+ Enable or disable the trayicon
+
+
+
+
+ Enable or disable run at startup
+
+
+
+
+ Check the configuration for errors
+
+
+
+
+ Show the help message in the capture mode
+
+
+
+
+ Define the main UI color
+
+
+
+
+ Define the contrast UI color
+
+
+
+
+ Print raw PNG capture
+
+
+
+
+ Print geometry of the selection in the format W H X Y. Does nothing if raw is specified
+
+
+
+
+ Define the screen to capture (starting from 0)
+
+
+
+
+ Invalid delay, it must be a number greater than 0
+
+
+
+
+ Invalid region, use 'WxH+X+Y' or 'all' or 'screen0/screen1/...'.
+
+
+
+
+ Invalid path, must be an existing directory or a new file in an existing directory
+
+
+
+ Define the screen to capture
+ Define the screen to capture
+
+
+
+ default: screen containing the cursor
+
+
+
+
+ Screen number
+
+
+
+
+ Invalid color, this flag supports the following formats:
+- #RGB (each of R, G, and B is a single hex digit)
+- #RRGGBB
+- #RRRGGGBBB
+- #RRRRGGGGBBBB
+- Named colors like 'blue' or 'red'
+You may need to escape the '#' sign as in '\#FFF'
+
+
+
+ Invalid delay, it must be higher than 0
+ Invalid delay, it must be higher than 0
+
+
+
+ Invalid screen number, it must be non negative
+
+
+
+ Invalid path, it must be a real path in the system
+ Invalid path, it must be a real path in the system
+
+
+
+ Invalid value, it must be defined as 'true' or 'false'
+
+
+
+
+ Error
+
+
+
+
+ Unable to write in
+
+
+
+
+ Requested screen exceeds screen count
+
+
+
+
+ Full screen screenshot pinned to screen
+
+
+
+ URL copied to clipboard.
+ L'URL s'ha copiat al porta-retalls.
+
+
+
+ Options
+
+
+
+
+ Arguments
+
+
+
+
+ arguments
+
+
+
+
+ Usage
+
+
+
+
+ options
+
+
+
+
+ Per default runs Flameshot in the background and adds a tray icon for configuration.
+
+
+
+
+ Hello, I'm here! Click icon in the tray to take a screenshot or click with a right button to see more options.
+
+
+
+ Toggle side panel
+ Toggle side panel
+
+
+ Resize selection left 1px
+ Resize selection left 1px
+
+
+ Resize selection right 1px
+ Resize selection right 1px
+
+
+ Resize selection up 1px
+ Resize selection up 1px
+
+
+ Resize selection down 1px
+ Resize selection down 1px
+
+
+ Select entire screen
+ Select entire screen
+
+
+ Move selection left 1px
+ Move selection left 1px
+
+
+ Move selection right 1px
+ Move selection right 1px
+
+
+ Move selection up 1px
+ Move selection up 1px
+
+
+ Move selection down 1px
+ Move selection down 1px
+
+
+ Commit text in text area
+ Commit text in text area
+
+
+ Delete current tool
+ Delete current tool
+
+
+
+ Quit capture
+
+
+
+
+ Screenshot history
+
+
+
+
+ Capture screen
+
+
+
+
+ Show color picker
+
+
+
+
+ Change the tool's size
+
+
+
+ Change the tool's thickness
+ Canvia el gruix de l'eina
+
+
+
+ RectangleTool
+
+
+ Rectangle
+
+
+
+
+ Set the Rectangle as the paint tool
+
+
+
+
+ RedoTool
+
+
+ Redo
+
+
+
+
+ Redo the next modification
+
+
+
+
+ SaveTool
+
+
+ Save
+
+
+
+
+ Save screenshot to a file
+
+
+
+ Save the capture
+ Guarda la captura
+
+
+
+ ScreenGrabber
+
+
+ Unable to detect desktop environment (GNOME? KDE? Sway? ...)
+
+
+
+
+ Hint: try setting the XDG_CURRENT_DESKTOP environment variable.
+
+
+
+
+ Unable to capture screen
+
+
+
+
+ SelectionTool
+
+
+ Rectangular Selection
+
+
+
+
+ Set Selection as the paint tool
+
+
+
+
+ SetShortcutDialog
+
+
+ Set Shortcut
+
+
+
+
+ Enter new shortcut to change
+
+
+
+
+ Press Esc to cancel or ⌘+Backspace to disable the keyboard shortcut.
+
+
+
+
+ Press Esc to cancel or Backspace to disable the keyboard shortcut.
+
+
+
+
+ Flameshot must be restarted for changes to take effect.
+
+
+
+
+ ShortcutsWidget
+
+
+ Hot Keys
+
+
+
+
+ Available shortcuts in the screen capture mode.
+
+
+
+
+ Description
+
+
+
+
+ Key
+
+
+
+
+ Left Double-click
+
+
+
+
+ Toggle side panel
+
+
+
+
+ Resize selection left 1px
+
+
+
+
+ Resize selection right 1px
+
+
+
+
+ Resize selection up 1px
+
+
+
+
+ Resize selection down 1px
+
+
+
+
+ Select entire screen
+
+
+
+
+ Move selection left 1px
+
+
+
+
+ Move selection right 1px
+
+
+
+
+ Move selection up 1px
+
+
+
+
+ Move selection down 1px
+
+
+
+
+ Commit text in text area
+
+
+
+
+ Delete current tool
+
+
+
+
+ Capture screen
+
+
+
+
+ Screenshot history
+
+
+
+
+ SidePanelWidget
+
+ Active thickness:
+ Active thickness:
+
+
+ Active color:
+ Active color:
+
+
+ Press ESC to cancel
+ Press ESC to cancel
+
+
+
+ Active tool size:
+
+
+
+
+ Active Color:
+
+
+
+
+ Grab Color
+
+
+
+
+ SizeDecreaseTool
+
+
+ Decrease Tool Size
+
+
+
+
+ Decrease the size of the other tools
+
+
+
+
+ SizeIncreaseTool
+
+
+ Increase Tool Size
+
+
+
+
+ Increase the size of the other tools
+
+
+
+
+ SizeIndicatorTool
+
+
+ Selection Size Indicator
+
+
+
+
+ Show X and Y dimensions of the selection
+
+
+
+ Show the dimensions of the selection (X Y)
+ Mostra les mides de la selecció (X Y)
+
+
+
+ StrftimeChooserWidget
+
+
+ Century (00-99)
+
+
+
+
+ Year (00-99)
+
+
+
+
+ Year (2000)
+
+
+
+
+ Month Name (jan)
+
+
+
+
+ Month Name (january)
+
+
+
+
+ Month (01-12)
+
+
+
+
+ Week Day (1-7)
+
+
+
+
+ Week (01-53)
+
+
+
+
+ Day Name (mon)
+
+
+
+
+ Day Name (monday)
+
+
+
+
+ Day (01-31)
+
+
+
+
+ Day of Month (1-31)
+
+
+
+
+ Day (001-366)
+
+
+
+
+ Hour (00-23)
+
+
+
+
+ Hour (01-12)
+
+
+
+
+ Minute (00-59)
+
+
+
+
+ Second (00-59)
+
+
+
+
+ Full Date (%m/%d/%y)
+
+
+
+
+ Full Date (%Y-%m-%d)
+
+
+
+
+ Time (%H-%M-%S)
+
+
+
+
+ Time (%H-%M)
+
+
+
+
+ SystemNotification
+
+
+ Flameshot Info
+
+
+
+
+ TextConfig
+
+
+ StrikeOut
+
+
+
+
+ Underline
+
+
+
+
+ Bold
+
+
+
+
+ Italic
+
+
+
+
+ Left Align
+
+
+
+
+ Center Align
+
+
+
+
+ Right Align
+
+
+
+
+ TextTool
+
+
+ Text
+
+
+
+
+ Add text to your capture
+
+
+
+
+ TrayIcon
+
+
+ &Take Screenshot
+
+
+
+
+ &Open Launcher
+
+
+
+
+ &Configuration
+
+
+
+
+ &About
+
+
+
+
+ Check for updates
+
+
+
+
+ New version %1 is available
+
+
+
+
+ &Quit
+
+
+
+
+ &Latest Uploads
+
+
+
+
+ UIcolorEditor
+
+ UI Color Editor
+ Editor de color de la interfície
+
+
+
+ Change the color moving the selectors and see the changes in the preview buttons.
+
+
+
+
+ Select a Button to modify it
+
+
+
+
+ Main Color
+
+
+
+
+ Click on this button to set the edition mode of the main color.
+
+
+
+
+ Contrast Color
+
+
+
+
+ Click on this button to set the edition mode of the contrast color.
+
+
+
+
+ UndoTool
+
+
+ Undo
+
+
+
+
+ Undo the last modification
+
+
+
+
+ UpdateNotificationWidget
+
+
+ New Flameshot version %1 is available
+
+
+
+
+ Ignore
+
+
+
+
+ Later
+
+
+
+
+ Update
+
+
+
+
+ UploadHistory
+
+
+
+
+
+ Upload History
+
+
+
+
+ Screenshots history is empty
+
+
+
+
+ UploadLineItem
+
+
+
+
+
+ Form
+
+
+
+
+
+
+
+ TextLabel
+
+
+
+
+
+
+
+ Copy URL
+
+
+
+
+
+
+
+ Open In Browser
+
+
+
+
+ Confirm to delete
+
+
+
+
+ Are you sure you want to delete a screenshot from the latest uploads and server?
+
+
+
+
+ UtilityPanel
+
+
+ Close
+
+
+
+
+ <Empty>
+
+
+
+
+ VisualsEditor
+
+
+ Opacity of area outside selection:
+
+
+
+
+ UI Color Editor
+
+
+
+
+ Colorpicker Editor
+
+
+
+
+ Button Selection
+
+
+
+
+ Select All
+
+
+
+
+ color_widgets::ColorDialog
+
+
+ Pick
+
+
+
+
+ color_widgets::ColorPalette
+
+
+ Unnamed
+
+
+
+
+ color_widgets::ColorPaletteModel
+
+
+ Unnamed
+
+
+
+
+ %1 (%2 colors)
+
+
+
+
+ color_widgets::ColorPaletteWidget
+
+
+
+
+
+ Open a new palette from file
+
+
+
+
+
+
+
+ Create a new palette
+
+
+
+
+
+
+
+ Duplicate the current palette
+
+
+
+
+
+
+
+ Delete the current palette
+
+
+
+
+
+
+
+ Revert changes to the current palette
+
+
+
+
+
+
+
+ Save changes to the current palette
+
+
+
+
+
+
+
+ Add a color to the palette
+
+
+
+
+
+
+
+ Remove the selected color from the palette
+
+
+
+
+
+ New Palette
+
+
+
+
+
+ Name
+
+
+
+
+ GIMP Palettes (*.gpl)
+
+
+
+
+ Palette Image (%1)
+
+
+
+
+ All Files (*)
+
+
+
+
+
+ Open Palette
+
+
+
+
+ Failed to load the palette file
+%1
+
+
+
+
+ color_widgets::GradientEditor
+
+
+ Add Color
+
+
+
+
+ Remove Color
+
+
+
+
+ Edit Color...
+
+
+
+
+ color_widgets::GradientListModel
+
+
+ %1 (%2 colors)
+
+
+
+
+ color_widgets::Swatch
+
+
+ Clear Color
+
+
+
+
+ %1 (%2)
+
+
+
+
diff --git a/data/translations/Internationalization_eu.ts b/data/translations/Internationalization_eu.ts
index 36f467a6..4cbf7fca 100644
--- a/data/translations/Internationalization_eu.ts
+++ b/data/translations/Internationalization_eu.ts
@@ -225,7 +225,7 @@
Mouse Wheel
- Saguaren gurpila
+ Saguaren gurpila
@@ -235,7 +235,7 @@
Right Click
- Eskuin-klika
+ Eskuin-klika
@@ -255,7 +255,7 @@
Exit
- Irten
+ Irten
@@ -426,7 +426,7 @@ Sakatu Zuriunea alboko panela irekitzeko.
Esc
- Esc
+ Esc
@@ -444,7 +444,7 @@ Sakatu Zuriunea alboko panela irekitzeko.
Update
- Eguneratu
+ Eguneratu
@@ -485,7 +485,7 @@ Sakatu Zuriunea alboko panela irekitzeko.
Error
- Errorea
+ Errorea
@@ -800,7 +800,7 @@ Please solve them manually in the configuration file.
Error
- Errorea
+ Errorea
@@ -810,7 +810,7 @@ Please solve them manually in the configuration file.
URL copied to clipboard.
- Arbelean kopiatu da URLa.
+ URLa arbelean kopiatu da.
@@ -818,22 +818,22 @@ Please solve them manually in the configuration file.
New version %1 is available
- %1 bertsio berria eskuragarri dago
+ %1 bertsio berria eskuragarri dagoYou have the latest version
- Azken bertsioa duzu
+ Azken bertsioa duzuFailed to get information about the latest version.
- Ezin izan da azken bertsioari buruzko informazioa lortu.
+ Ezin izan da azken bertsioari buruzko informazioa lortu.Unable to connect via DBus
- Ezin da DBus bidez konektatu
+ Ezin da DBus bidez konektatu
@@ -1390,27 +1390,27 @@ Please solve them manually in the configuration file.
Uploading Image
- Irudia igotzen
+ Irudia kargatzenCopy URL
- Kopiatu URLa
+ Kopiatu URLaOpen URL
- Ireki URLa
+ Ireki URLaDelete image
- Ezabatu irudia
+ Ezabatu irudiaImage to Clipboard.
- Irudia arbelera.
+ Irudia arbelera.
@@ -1420,17 +1420,17 @@ Please solve them manually in the configuration file.
Unable to open the URL.
- Ezin da ireki URLa.
+ Ezin da ireki URLa.URL copied to clipboard.
- Arbelean kopiatu da URLa.
+ URLa arbelean kopiatu da.Screenshot copied to clipboard.
- Arbelean kopiatu da pantaila-argazkia.
+ Arbelean kopiatu da pantaila-argazkia.
@@ -1448,7 +1448,7 @@ Please solve them manually in the configuration file.
Image Uploader
- Irudi igotzailea
+ Irudi kargatzailea
@@ -1734,7 +1734,7 @@ Please solve them manually in the configuration file.
Copy to clipboard
- Kopiatu arbelean
+ Kopiatu arbelean
@@ -2295,7 +2295,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Toggle side panel
- Bistaratu/Ezkutatu alboko panela
+ Bistaratu/Ezkutatu alboko panela
@@ -2320,7 +2320,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Select entire screen
- Hautatu pantaila osoa
+ Hautatu pantaila osoa
@@ -2345,12 +2345,12 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Commit text in text area
- Idatzi testu-eremuan
+ Idatzi testua testu-eremuanDelete current tool
- Delete current tool
+ Ezabatu uneko tresna
@@ -2360,7 +2360,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Screenshot history
- Pantaila-argazkien erregistroa
+ Pantaila-argazkien erregistroa
@@ -2608,7 +2608,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
&Take Screenshot
- &Pantaila-argazkia egin
+ Egin &pantaila-argazkia
@@ -2618,32 +2618,32 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
&Configuration
- &Ezarpenak
+ &Ezarpenak&About
- &Honi buruz
+ &Honi buruzCheck for updates
- Bilatu eguneraketak
+ Bilatu eguneraketakNew version %1 is available
- %1 bertsio berria eskuragarri dago
+ %1 bertsio berria eskuragarri dago&Quit
- &Irten
+ &Irten&Latest Uploads
- &Azken igoerak
+ &Azken kargak
@@ -2732,7 +2732,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Screenshots history is empty
- Pantaila-argazkien erregistroa hutsik dago
+ Pantaila-argazkien erregistroa hutsik dago
@@ -2759,7 +2759,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Copy URL
- Kopiatu URLa
+ Kopiatu URLa
@@ -2772,12 +2772,12 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
Confirm to delete
- Berretsi ezabatzeko
+ Berretsi ezabatzeaAre you sure you want to delete a screenshot from the latest uploads and server?
- Ziur pantaila-argazkia azken igoeretatik eta zerbitzaritik ezabatu nahi duzula?
+ Ziur pantaila-argazkia azken kargetatik eta zerbitzaritik ezabatu nahi duzula?
@@ -2803,7 +2803,7 @@ Baliteke '#' karakterea ihes egin behar izatea, '\#FFF'n bez
UI Color Editor
- Interfaze-kolorearen editorea
+ Interfazearen kolorearen editorea